#!/bin/bash

set -e

# $1: source package name
# $2: distribution
function get_sources() {
	apt-get source --only-source -t $2 $1
	local version=$(rmadison $1 --architecture=all,amd64 -s $2 | head -n1 | cut -d\| -f2 | sed s"/ //g" | sed s"/\-.*$//g")
	cd $1-$version
}

# $1: source package name
# $2: git repository
# $3: (optional) specifc branch or tag
function get_git_sources() {
	git clone $2 $1
	cd $1
	if [[ ! -z $3 ]] # checks if $3 is not empty
	then 
		git checkout $3
	else
		git tag --sort "version:refname" -l | tail -n1 | xargs git checkout
	fi
}

# $1: patch directory name
function import_patches() {
	shopt -s nullglob
	for patch in ../patches/$1/*.patch ; do
	    quilt import $patch
	    quilt push
	done
}

# $1: patch directory name
function apply_patches_manually() {
	shopt -s nullglob
	for patch in ../patches/$1/*.patch ; do
		patch -p1 < $patch
	done
}

# $1: changelog entry
function dch_custom() {
	debchange --local ~fsmpi+ $1
}

function dch_backport() {
	local version=$(cat /etc/os-release | grep VERSION_ID= | sed -E 's/.*([0-9]+).*/\1/')
	local name=$(cat /etc/os-release | grep VERSION= | sed 's/.*(\(.*\)).*/\1/')
	debchange --local ~bpo$version+ --distribution $name-backports "Rebuild for $name-backports."
}

function install_build_deps() {
	mk-build-deps --install --remove --tool "apt-get -o Debug::pkgProblemResolver=yes --no-install-recommends --yes"
}

function build() {
	debuild -us -uc -nc
}

function test_install() {
    # TODO at the time of writing, this plainly fails with dependency errors
    #      also it cannot automatically work around multiple conflicting packages
    #debi --with-depends
    :
}

function prepare_artifacts() {
	cd ..
	mkdir -p packages sources debug
	shopt -s nullglob
	for f in *dbgsym*.deb ; do
		mv -t debug $f
	done
	for f in *.deb ; do
		mv -t packages $f
	done
	for f in *.tar.gz *.changes *.dsc ; do
		mv -t sources $f
	done
}
